@@ -1,4 +1,4 @@
-from classifier_free_guidance_pytorch.classifier_free_guidance_pytorch import TextConditioner
+from classifier_free_guidance_pytorch.classifier_free_guidance_pytorch import TextConditioner, AttentionTextConditioner
 from classifier_free_guidance_pytorch.classifier_free_guidance_pytorch import classifier_free_guidance
 
 from classifier_free_guidance_pytorch.open_clip import OpenClipAdapter
